@@ -1,26 +1,26 @@
-#' Continuous interactive session with RevBayes
+#' Interactive Session with RevBayes
 #'
 #'    Simulates a continuous, interactive session with RevBayes. While this session is active, all code will be interpreted as Rev code, and attempting to run R code may result in error.
 #'
 #'    By default, the interactive session uses the present R working directory as the RevBayes working directory. This behavior can be turned off with use_wd = FALSE
 #'
-#'    The exit the session, type 'quit()' or hit the 'esc' key.
+#'    The exit the session, type 'quit()', 'q()', or hit the 'esc' key.
 #
-#'    clearRev(), getRevVars(), and getRevHistory can be called from within the session for user convenience
+#'    clearRev(), getRevVars(), and getRevHistory() can still be called from within the session for user convenience
 #'
-#'@param path Path to the RevBayes executable. Defaults to Sys.getenv("RevBayesPath"), so
-#'    initRev() should be called first.
+#'@param path character - Path to the RevBayes executable. Defaults to Sys.getenv("rb"), which should be assigned upon first loading the package.
 #'
-#'@param viewCode If TRUE, code from the temporary file used to interact with
-#'    RevBayes will be displayed in the viewing pane. Default is FALSE.
+#'@param viewCode logical - If TRUE, code from the temporary file used to interact with RevBayes will be displayed in
+#'                the viewing pane. Default is FALSE. The option is mostly for developer convenience, and can be ignored
+#'                by most users.
 #'
-#'@param coerce If FALSE, output from RevBayes will be printed to the console in character format. If
-#'    TRUE, repRev() will attempt to coerce output into a suitable R object. Default is FALSE.
+#'@param coerce logical - If FALSE, RevBayes output will be printed to the console in character format. If
+#'    TRUE, coerceRev() will attempt to coerce output into a suitable R object. Default is TRUE.
 #'
-#'@param use_wd If TRUE, the simulated Revbayes session will use the same working directory as
-#'    the active R session. If FALSE, it will use its default. Default is TRUE.
+#'@param use_wd logical - If TRUE, the simulated Revbayes session will use the same working directory as
+#'    the active R session. If FALSE, it will use the default for the RevBayes executable. Default is TRUE.
 #'
-#'@return No return. Acts as an interactive session with the RevBayes. RevBayes output is printed to the console via cat(), and Rev variables can be referenced externally via doRev() and getRevObj().
+#'@return No return. RevBayes variables assigned within the session can be accessed externally via doRev() or viewed with getRevVars().
 #'
 #'@examples
 #' \dontrun{
@@ -37,10 +37,10 @@
 #'}
 #'@export
 #'
-repRev <- function (path = Sys.getenv("RevBayesPath"), viewCode = FALSE, coerce = FALSE, use_wd = TRUE)
+repRev <- function (path = Sys.getenv("rb"), viewCode = FALSE, coerce = TRUE, use_wd = TRUE)
 {
   while (TRUE) {
-    ginput <- readline(prompt = "rb>>>")
+    ginput <- readline(prompt = "rb>>> ")
 
     numberOfOpenBraces <- stringr::str_count(ginput, "\\{")
     numberOfClosedBraces <- stringr::str_count(ginput, "\\}")
@@ -55,10 +55,10 @@ repRev <- function (path = Sys.getenv("RevBayesPath"), viewCode = FALSE, coerce
 
       if(
         (numberOfOpenBraces < numberOfClosedBraces) |
-        (numberOfOpenBraces < numberOfClosedBraces)
+        (numberOfOpenParenthesis < numberOfClosedParenthesis)
       ) break();
 
-      ginput <- ginput %+% readline(prompt <- "rb>>>")
+      ginput <- ginput %+% "\n" %+% readline(prompt <- "rb>>> ")
 
       numberOfOpenBraces <- stringr::str_count(ginput, "\\{")
       numberOfClosedBraces <- stringr::str_count(ginput, "\\}")
@@ -74,37 +74,27 @@ repRev <- function (path = Sys.getenv("RevBayesPath"), viewCode = FALSE, coerce
     if (ginput == "quit()" || ginput == "q()") {
       break
     }
-
-    if (ginput == "clearRev()"){
+    else if (ginput == "clearRev()"){
       clearRev()
       next
     }
-
-    if(str_detect(ginput, "clearRev\\(([0-9]+)\\)")){
+    else if(str_detect(ginput, "clearRev\\(([0-9]+)\\)")){
       clearRev(as.integer(str_extract(ginput, "[0-9]+")))
       next
     }
-
-    if(ginput == "getRevVars()"){
+    else if(ginput == "getRevVars()"){
       cat(getRevVars(), sep = "\n")
       next()
     }
-
-    if(str_detect(ginput, pattern = "^getRevVars\\(\".+\"\\)$")){
-      args <- str_remove_all(str_extract(ginput, "\\(.+\\)"), "\\(|\\)|\"")
-      cat(getRevVars(args), sep = "\n")
-      next()
-    }
-
-
-    if(ginput == "getRevHistory()"){
+    else if(ginput == "getRevHistory()"){
       cat(getRevHistory(), sep = "\n")
       next()
     }
-
-
-    else{cat(doRev(ginput, viewCode = viewCode, coerce = coerce), sep = "\n\n")}
-
-
+    else{
+      if(coerce)
+        cat(capture.output(doRev(ginput, viewCode = viewCode, coerce = coerce)), sep = "\n")
+      else
+        cat(doRev(ginput, viewCode = viewCode, coerce = coerce), sep = "\n")
+    }
   }
 }
